%=======================================================================
% test different functions of "a" for Cl/Mg
%=======================================================================
clear;

%--------------------------------------------------------------------------
%% Chemistry data
%--------------------------------------------------------------------------
dat=load('../data/Waterdatabaserev6.reformatted.txt');
ii=find(dat(:,7)>0 & dat(:,2)<20.3);
clmg=dat(ii,7);
lon=dat(ii,1); lat=dat(ii,2); yr=dat(ii,end);
[xd yd]=d2u(lon,lat,'4');

%--------------------------------------------------------------------------
%% Flow Model
%--------------------------------------------------------------------------
figure(1); clf;

for (iwhich=1:2);
if (iwhich==1);
  dat=load('../data/Whittier_WHaw_flowvector_reformatted.txt');
  x0=793000; y0=2120400;  z0=0; nx=475; ny=475; nz=4; dx=95000/nx; dy=95000/ny; dz=4/nz;
else;
  dat=load('../data/Whittier_BI_flowvector_reformatted.txt');
   x0=806000; y0=2091000;  z0=49.5235; nx=272; ny=310; nz=3; dx=136000/nx; dy=155000/ny; dz=1000/nz;
end;

nn=nx*ny*nz;
x=zeros(nx*ny,1); y=x; z=x;
y1=y0+dy*ny;
n=0;
for i=1:ny;
for j=1:nx;
    n=n+1;
    x(n)=x0+dx/2+(j-1)*dx;
    y(n)=y1-dy/2-(i-1)*dy;
end
end

vx=zeros(nx*ny,1); vy=vx;
for lyr=1:nz;
vx=vx+dat((lyr-1)*n+1:lyr*n,2); vy=vy+dat((lyr-1)*n+1:lyr*n,3);
end;
vx=vx./nz; vy=vy./nz;
X=reshape(x,nx,ny)'; Y=reshape(y,nx,ny)';
Vx=reshape(vx,nx,ny)'; Vy=reshape(vy,nx,ny)';


%-------------------------------------------------------------------------
%% water trajectories
%-------------------------------------------------------------------------

if (iwhich==1);
  dq=16;
  ii=find(clmg>15 & 8e5<xd & xd< 8.5e5 & 2.15e6<yd & yd<2.2e6);
  step=0.2;
else;
  dq=6;
  ii=find(clmg>15 & (8e5>xd | xd> 8.5e5 | 2.15e6>yd | yd>2.2e6) & xd>min(X(1,:)) & xd<max(X(1,:)) & yd <max(Y(:,1)) & yd>min(Y(:,1)));
  step=0.1;
end;
nt=length(ii);

V=sqrt(Vx.^2+Vy.^2);
Vxn=Vx./V; Vyn=Vy./V;
haw=load('../data/hawaii_with_utm.txt');
plot(haw(:,3),haw(:,4),'k-','LineWidth',2); hold on;
%quiver(X(1:dq:end,1:dq:end),Y(1:dq:end,1:dq:end),Vxn(1:dq:end,1:dq:end),Vyn(1:dq:end,1:dq:end),'k')
zclmg=(log(clmg(ii))-1.6292)/0.99847-1.085;
kk=find(zclmg>0);
xxd=xd(ii);yyd=yd(ii);
xxd=xxd(kk); yyd=yyd(kk);
zclmg=zclmg(kk);
%xxd(end+1)=8e5; yyd(end+1)=2.1e6;
kk=find(zclmg>2);
zclmg(kk)=2;

scatter(xxd,yyd,100,zclmg,'fill');
axis([8 9.5 20.8 22.6]*1e5);
colorbar

for k=1:nt;
xy=stream2(X,Y,-Vx,-Vy,xd(ii(k)),yd(ii(k)),step);
traj=cell2mat(xy');
[ro co]=size(traj);
if (ro>5);
if (k==1);
    out=[traj clmg(ii(k))*ones(length(traj),1)];
else
    out=[out; [traj clmg(ii(k))*ones(length(traj),1)];];
end
end;
plot(traj(:,1),traj(:,2),'r');
end;

%-------------------------------------------------------------------------
%% Plots
%-------------------------------------------------------------------------
%colorbar
axis([7.8 9.4 20.8 22.6]*1e5);
axis equal

[lat lon]=u2d(out(:,1),out(:,2),4);
if (0)
if (iwhich==1);
fid=fopen('../data/BI_WHaw_traj_clmg.lld','w');
fprintf(fid,'%10.6f %10.6f %6.1f \n',[lon lat out(:,3)]');
fclose(fid);
else
fid=fopen('../data/BI_traj_clmg.lld','w');
fprintf(fid,'%10.6f %10.6f %6.1f \n',[lon lat out(:,3)]');
fclose(fid);
end;
end;

end;


