%=======================================================================
% test different functions of "a" for Cl/Mg
%=======================================================================
clear;
%--------------------------------------------------------------------------
%% Chemistry data
%--------------------------------------------------------------------------
dat=load('../data/Waterdata_with_utm.txt');
ii=find(dat(:,9)>0);
clmg=dat(ii,9);
lon=-dat(ii,3); lat=dat(ii,4); yr=dat(ii,end);
xd=dat(ii,1); yd=dat(ii,2);
SiO=dat(ii,6);

%--------------------------------------------------------------------------
%% Flow Model
%--------------------------------------------------------------------------
dat=load('../data/Whittier_WHaw_flowvector_reformatted.txt');
x0=793000; y0=2120400;  z0=0; nx=475; ny=475; nz=4; dx=95000/nx; dy=95000/ny; dz=4/nz;
dat=load('../data/Whittier_BI_flowvector_reformatted.txt');
x0=806000; y0=2091000;  z0=49.5235; nx=272; ny=310; nz=3; dx=136000/nx; dy=155000/ny; dz=1000/nz;

nn=nx*ny*nz;
x=zeros(nx*ny,1); y=x; z=x;
y1=y0+dy*ny;
n=0;
for i=1:ny;
for j=1:nx;
    n=n+1;
    x(n)=x0+dx/2+(j-1)*dx;
    y(n)=y1-dy/2-(i-1)*dy;
end
end

vx=zeros(nx*ny,1); vy=vx;
for lyr=1:nz;
vx=vx+dat((lyr-1)*n+1:lyr*n,2); vy=vy+dat((lyr-1)*n+1:lyr*n,3);
end;
vx=vx./nz; vy=vy./nz;
X=reshape(x,nx,ny)'; Y=reshape(y,nx,ny)';
Vx=reshape(vx,nx,ny)'; Vy=reshape(vy,nx,ny)';


%-------------------------------------------------------------------------
%% water trajectories
%-------------------------------------------------------------------------
haw=load('../data/hawaii_with_utm.txt');
dq=4;
ii=find(clmg>15 & 8e5<xd & xd< 8.5e5 & 2.15e6<yd & yd<2.2e6);
ii=find(clmg>15 & (8e5>xd | xd> 8.5e5 | 2.15e6>yd | yd>2.2e6) & xd>min(X(1,:)) & xd<max(X(1,:)) & yd <max(Y(:,1)) & yd>min(Y(:,1)));
nt=length(ii);

figure(1); clf;
V=sqrt(Vx.^2+Vy.^2);
Vxn=Vx./V; Vyn=Vy./V;
plot(haw(:,3),haw(:,4),'k-','LineWidth',2); hold on;
quiver(X(1:dq:end,1:dq:end),Y(1:dq:end,1:dq:end),Vxn(1:dq:end,1:dq:end),Vyn(1:dq:end,1:dq:end))
scatter(xd(ii),yd(ii),50,log10(clmg(ii)),'fill');
axis([8 9.5 20.8 22.6]*1e5);

for k=1:nt;
xy=stream2(X,Y,-Vx,-Vy,xd(ii(k)),yd(ii(k)),0.05);
traj=cell2mat(xy');
[ro co]=size(traj);
if (ro>5);
if (k==1);
    out=[traj clmg(ii(k))*ones(length(traj),1)];
else
    out=[out; [traj clmg(ii(k))*ones(length(traj),1)];];
end
end;
plot(traj(:,1),traj(:,2),'r');
end;

%-------------------------------------------------------------------------
%% Plots
%-------------------------------------------------------------------------
%colorbar
axis([7.8 9.4 20.8 22.6]*1e5);
axis equal

[lat lon]=u2d(out(:,1),out(:,2),4);

fid=fopen('../data/BI_traj_clmg.lld','w');
fprintf(fid,'%10.6f %10.6f %6.1f \n',[lon lat out(:,3)]');
fclose(fid)


