%==========================================
% Converts Flinders density model to a map of probability
%==========================================
opengl software
if (exist('Rho','var')==0);
    clear
    load COMBINED_3sub_GRAV3d.mat
    Rho=D1_G;
    clear D*
    clear *3* *2*
end;
size_D=size(Rho);
ny=size_D(1); nx=size_D(2);
km=1e3;
CUT_OFF=0.1
Z_LVL=-15000;  
k=find(abs(Z - Z_LVL)==min(abs(Z - Z_LVL)));
Xbound=[805 930]; Ybound=[2093 2250];
%Xbound=[840 870];
%-------------------------------------------------------------
% Plot Densities
%-------------------------------------------------------------
if (1);
f=figure(10);
clf
p0=patch(isosurface(X1_G/km, Y1_G/km, Z1_G/km,Rho,CUT_OFF));
set(p0,'FaceColor',[1 0.5 0],'EdgeColor','none');
xlabel('X (km)');
ylabel('Y (km)');
zlabel('Z (km)');
set(gca,'Zlim',[min(Z)/km 0]);
box on;

daspect([1,1,1])
camlight (-10,-60); lighting phong; camlight(30,0)
  set(gcf,'Renderer','zbuffer');
camproj('perspective')
%lighting gouraud
view(-16,48);
alpha(1)
hold on
size_D=size(Rho);
h=surf(X1_G(:,:,k)/km,Y1_G(:,:,k)/km,Z_LVL*ones(size_D(1),size_D(2))/km,Rho(:,:,k))
set(h,'EdgeColor','none')
col = jet(1024);
colormap(col)
colorbar;
%caxis([-CUT_OFF CUT_OFF])
%alpha(.2)
axis tight
end;
%---------------------------------------------------------------
% Compute depth averaged rho
%--------------------------------------------------------------------------
mcprob=zeros(ny,nx);
mrho=zeros(ny,nx);
for j=1:ny;
    for i=1:nx;
        ii=find(isnan(squeeze(Rho(j,i,:)))==0);
        mrho(j,i)=sum(Rho(j,i,ii))./length(ii);
    end;
end;

%--------------------------------------------------------------------------
% Compute CDFs
%--------------------------------------------------------------------------
dg=0.005;
rhogrid=[-0.2:dg:0.6];
figure(30);
igood=find(X1_G(:,:,1)/km>=Xbound(1) & X1_G(:,:,1)/km<=Xbound(2)....
      & Y1_G(:,:,1)/km>=Ybound(1) & Y1_G(:,:,1)/km<=Ybound(2));
rhocounts=histc(mrho(igood),rhogrid);

area=trapz(rhogrid,rhocounts)/dg;
pfunct=rhocounts./area;
rhocdf=cumsum(pfunct);

subplot(311);
bar(rhogrid,rhocounts);
xlabel('\rho kg/m^3');
ylabel('counts');
grid on;

subplot(312);
bar(rhogrid,pfunct);
xlabel('\rho kg/m^3');
ylabel('Normalized Counts');
grid on;

cprob0=0.98;
[dum,i,j]=unique(rhocdf);
rho0=interp1(rhocdf(i),rhogrid(i),cprob0)
subplot(313);
plot(rhogrid(i),rhocdf(i),'.'); hold on;
plot([min(rhogrid) rho0 rho0],[cprob0 cprob0 0]);
xlabel('\rho kg/m^3');
ylabel('cdf');
grid on;

%--------------------------------------------------------------------------
% p values of each depth-averaged rho 
%--------------------------------------------------------------------------
mcprob=interp1(rhogrid,rhocdf,mrho);

%--------------------------------------------------------------------------
figure(1); clf;
pcolor(squeeze(X1_G(:,:,1))/km,squeeze(Y1_G(:,:,1))/km,mcprob);
shading interp
xlabel('Easting (km)');
ylabel('Northing (km)');
colorbar;
axis([Xbound Ybound]);

if (0);

out=zeros(nx*ny,3);
dum=squeeze(X1_G(:,:,1));
out(:,1)=dum(:);
dum=squeeze(Y1_G(:,:,1));
out(:,2)=dum(:);
out(:,3)=mcprob(:);
[lat,lon]=u2d(out(:,1),out(:,2),'4N');
out(:,1)=lon;
out(:,2)=lat;

fid=fopen('depthmeanprob.llp','w');
fprintf(fid,'%10.6f %10.6f %9.4f \n',out');
fclose(fid);
end;


