%=======================================================================
% test different functions of "a" for Cl/Mg
%=======================================================================
clear;
iwest=0;
figure(1); clf;
for iwest=1:2;
%--------------------------------------------------------------------------
%% Chemistry data
%--------------------------------------------------------------------------
dat=load('../data/Waterdatabaserev6.reformatted.txt');
ii=find(dat(:,7)>0 & dat(:,2)<21.25 & dat(:,2)>20.5);
clmg=dat(ii,7);
lon=dat(ii,1); lat=dat(ii,2); yr=dat(ii,end);
[xd yd]=d2u(lon,lat,'4');
jj=find(clmg>=15);
outd=[lon(jj) lat(jj) clmg(jj)];
fid=fopen('clmg.lld','w');
fprintf(fid,'%10.6f %10.6f %6.1f \n',outd');
fclose(fid);

%--------------------------------------------------------------------------
%% Flow Model
%--------------------------------------------------------------------------
if (iwest==1);
dat=load('../data/Whittier_w_maui_flow_reformatted.txt');
x0=738000; y0=2298000;  z0=0; nx=310; ny=300; nz=4; dx=31000/nx; dy=31000/ny; dz=4/nz;
else;
dat=load('../data/Whittier_e_maui_flow_reformatted.txt');
x0=759000; y0=2276000;  z0=100; nx=280; ny=220; nz=4; dx=56000/nx; dy=44000/ny; dz=1000/nz;
end;

nn=nx*ny*nz;
x=zeros(nx*ny,1); y=x; z=x;
y1=y0+dy*ny;
n=0;
for i=1:ny;
for j=1:nx;
    n=n+1;
    x(n)=x0+dx/2+(j-1)*dx;
    y(n)=y1-dy/2-(i-1)*dy;
end
end

vx=zeros(nx*ny,1); vy=vx;
for lyr=1:nz;
vx=vx+dat((lyr-1)*n+1:lyr*n,1); vy=vy+dat((lyr-1)*n+1:lyr*n,2);
end;
vx=vx./nz; vy=vy./nz;
X=reshape(x,nx,ny)'; Y=reshape(y,nx,ny)';
Vx=reshape(vx,nx,ny)'; Vy=reshape(vy,nx,ny)';


%-------------------------------------------------------------------------
%% water trajectories
%-------------------------------------------------------------------------
step=0.1;
coast=load('../data/Maui.dat');
[xcoast ycoast, zone,zonlims]=d2u(coast(:,1),coast(:,2),'4');
dq=4;
ii=find(clmg>15 & x0<xd & xd < (x0+dx*nx) & y0 < yd & yd<(y0+dy*ny));
%ii=find(clmg>15 & (8e5>xd | xd> 8.5e5 | 2.15e6>yd | yd>2.2e6) & xd>min(X(1,:)) & xd<max(X(1,:)) & yd <max(Y(:,1)) & yd>min(Y(:,1)));
nt=length(ii);


V=sqrt(Vx.^2+Vy.^2);
Vxn=Vx./V; Vyn=Vy./V;
plot(xcoast, ycoast,'k-','LineWidth',2); hold on;
quiver(X(1:dq:end,1:dq:end),Y(1:dq:end,1:dq:end),Vxn(1:dq:end,1:dq:end),Vyn(1:dq:end,1:dq:end))
scatter(xd(ii),yd(ii),50,log10(clmg(ii)),'fill');
axis([7.38 8.2 22.73 23.3]*1e5);
axis equal
beenhere=0;

for k=1:nt;
if yd(ii(k))==min(yd(ii))
    yd(ii(k))=yd(ii(k))+1100;  %This well is just at the boader of the flow model
    xd(ii(k))=xd(ii(k))-150;
end;
xy=stream2(X,Y,-Vx,-Vy,xd(ii(k)),yd(ii(k)),step);
traj=cell2mat(xy');
[ro co]=size(traj);
if (ro>5);
if (beenhere==0);
    out=[traj clmg(ii(k))*ones(length(traj),1)];
    beenhere=1;
else
    out=[out; [traj clmg(ii(k))*ones(length(traj),1)];];
end
end;
plot(traj(:,1),traj(:,2),'r');
end;

%-------------------------------------------------------------------------
%% OUTPUT
%-------------------------------------------------------------------------
%colorbar


[lat lon]=u2d(out(:,1),out(:,2),4);
if (iwest==1);
fid=fopen('../MN/WMaui_traj_clmg.lld','w');
else;
fid=fopen('../MN/EMaui_traj_clmg.lld','w');
end
fprintf(fid,'%10.6f %10.6f %6.1f \n',[lon lat out(:,3)]');
fclose(fid)
end;


