%========================================================================
% Show Pr vs data for different datasets
%========================================================================
clear;
prior=0.06; 
w0=log(prior)-log(1-prior)
Prc_grav=0.8; zcrit_grav=1.5;
Prc_rift=Prc_grav*0.75;  dcrit_rift=1.0;
Prc_vent=Prc_grav*0.56; dcrit_vent=1.0;
Prc_clmg=Prc_grav; dcrit_clmg=1000;  dthresh_clmg=15;
Prc_sio=0.75*Prc_grav; dcrit_sio=5.5; zt_sio=1;
Prc_sio=0.75*Prc_grav; dcrit_sio=500; zt_sio=1;
Prc_welltemp=Prc_grav*1.125; dcrit_welltemp=8; zt_temp=1;

bins=100;
nbins=100;

xl=0.11; yt=0.88;
ph=0.08; pw=0.28; dx=0.035; dy=0.06; ybuf=0.03;
yt=0.8; pw=0.3; ph=0.17; ph2=0.04; dy=0.05; ybuf=0.01;
textfac=1.1;
xrev=0;
figure(1); clf;
%------------------------------------------------------
% Gravity
%-----------------------------------------------------
Prc=Prc_grav;
file=load('data/residual_subaerial.llre');
d=file(:,3);
med=median(d); mad=1.482*median(abs(d-med));
zd=(d-med)./mad;

zcrit=zcrit_grav;       %Zero-age value
dcrit=med+zcrit*mad;  %Data value set based on zero-age data
dthresh=0;
zt=0;

d0=dcrit.*[-0.75:0.01:1.5]'; %range of zero-age gravity (also full range of transformed data)
z0=(d0-med)/mad;           %z of transformed data (all ages)
w=(log(Prc/(1-Prc))-w0)./zcrit;
Pr=1./(1+exp(-w0-w.*z0));

pos1=[xl yt pw ph]; 
pos2=[xl yt-(dy+ph2) pw ph2];
xlab='RGA (mGal)'; 
xlimit=[min(z0) max(z0)];

Pdat_rel_plot;

disp(['gravity: med, mad, w, dcrit, zcrit=' num2str([med mad w dcrit zcrit])]);
%------------------------------------------------------
% Rift Zones
%-----------------------------------------------------
Prc=Prc_rift;
dmin=1e-10;
R=5;
if (exist('data/all_islands_riftzones_prox.llr','var')==0);
format long
!gmtset D_FORMAT %.6f
!grd2xyz BI/prox_riftzones_negsubmarine.grd -S >! junk
!grd2xyz MN/prox_riftzones_negsubmarine.grd >> junk
!grd2xyz Oahu/prox_riftzones_negsubmarine.grd >> junk
!grd2xyz Kauai/prox_riftzones_negsubmarine.grd >> junk
!awk '{if ($3 > 0) print $1, $2, $3}' junk >! data/all_islands_riftzones_prox.llr
end;

dat=load('data/all_islands_riftzones_prox.llr');
d=exp(-dat(:,3)./R); 
med=median(d); mad=1.482*median(abs(d-med));
zd=(d-med)./mad;
zt=0;
dthresh=0;
xrev=1;

d0=[0.0:0.1:10]; dcrit=0;
a0=exp(-d0./R);
acrit=exp(-dcrit./R);
zcrit=(acrit-med)./mad;
z0=(a0-med)./mad;
w=(log(Prc/(1-Prc))-w0)./zcrit; %Solve for weight based on zcrit 
Pr=1./(1+exp(-w0-w.*z0));

pos1=[xl yt-(dy+ph)-(dy+ph2)-ybuf pw ph];
pos2=[xl yt-(dy+ph)-2*(dy+ph2)-ybuf pw ph2];
xlab=('Distance from Rift zone (km)');
xlimit=[min(zd)-0.1 max(zd)+0.1];
Pdat_rel_plot;

disp(['riftzones: med, mad, w, dcrit, zcrit=' num2str([med mad w dcrit zcrit])]);
xrev=0;

%------------------------------------------------------
% Vents;
%-----------------------------------------------------
Prc=Prc_vent;
dmin=1e-7;
R=1.5;
if (exist('data/all_islands_vents_prox.llr','var')==0);
format long
!gmtset D_FORMAT %.6f
!grd2xyz BI/prox_vents_negsubmarine.grd -S >! junk
!grd2xyz MN/prox_vents_negsubmarine.grd >> junk
!grd2xyz Oahu/prox_vents_negsubmarine.grd >> junk
!grd2xyz Kauai/prox_vents_negsubmarine.grd >> junk
!awk '{if ($3 > 0) print $1, $2, $3}' junk >! data/all_islands_vents_prox.llr
end;

dat=load('data/all_islands_vents_prox.llr');
d=exp(-dat(:,3)./R); 
med=median(d); mad=1.482*median(abs(d-med));
zd=(d-med)./mad;
zt=0;
dthresh=0;
xrev=1;

d0=[0.0:0.1:10]; dcrit=0;
a0=exp(-d0./R);
acrit=exp(-dcrit./R);
zcrit=(acrit-med)./mad;
z0=(a0-med)./mad;
w=(log(Prc/(1-Prc))-w0)./zcrit; %Solve for weight based on zcrit 
Pr=1./(1+exp(-w0-w.*z0));

pos1=[xl yt-2*((dy+ph)+(dy+ph2)+ybuf) pw ph];
pos2=[xl yt-2*((dy+ph)+(dy+ph2)+ybuf)-(dy+ph2)-ybuf pw ph2];
xlab='Distance from Vents (km)';
xlimit=[min(zd)-2 max(zd)+2];
Pdat_rel_plot;

disp(['vents: med, mad, w, dcrit, zcrit=' num2str([med mad w dcrit zcrit])]);
xrev=0;

%------------------------------------------------------
% Cl/Mg
%-----------------------------------------------------
Prc=Prc_clmg;
dcrit=(dcrit_clmg);
dthresh=dthresh_clmg;

dat=load('data/Waterdatabaserev5_reformatted.txt');
ii=find(dat(:,7)>0 & dat(:,1)~=0);
d=log(dat(ii,7));
med=median(d); mad=1.482*median(abs(d-med));
zd=(d-med)./mad;
zt=(log(dthresh)-med)./mad;

d0=dcrit*[0:0.01:1.2]';
z0=(log(d0)-med)./mad;
z0=max([z0-zt zeros(size(z0))]')';
zcrit=(log(dcrit)-med)/mad-zt;

w=(log(Prc/(1-Prc))-w0)./zcrit;
Pr=1./(1+exp(-w0-w.*z0));

pos1=[xl+(pw+2*dy) yt pw ph]; 
pos2=[xl+(pw+2*dy) yt-(dy+ph2) pw ph2];
xlab='Cl/Mg';
xlimit=[min(z0) max(z0)];

Pdat_rel_plot;
disp(['Cl/Mg: med, mad, w, zt dcrit zcrit =' num2str([med mad w zt dcrit zcrit])]);
%------------------------------------------------------
% SiO2
%------------------------------------------------------
Prc=Prc_sio;
dat=load('data/SiO2_lnZ1_reformatted.txt');
aq=dat(:,1); lon=dat(:,2); lat=dat(:,3); sio=dat(:,4); lsio=dat(:,5); zd=dat(:,6);
med=3.84; mad=0.26;  %Means of Dave's table fpr APPROXIMATE case
med=median(lsio); mad=1.482*median(abs(lsio-med)); % APPROXIMATE 

zt=zt_sio;
dthresh=exp(mad*(zt)+med);
dcrit=dcrit_sio;
zcrit=(log(dcrit)-med)./mad;

d0=[0:0.01:1.2]'*dcrit;
z0=(log(d0)-med)./mad;
z0=max([z0-zt zeros(size(z0))]')';

w=(log(Prc/(1-Prc))-w0)./(zcrit-zt); 
Pr=1./(1+exp(-w0-w.*z0));
pos1=[xl+pw+2*dy yt-(dy+ph)-(dy+ph2)-ybuf pw ph];
pos2=[xl+pw+2*dy yt-(dy+ph)-2*(dy+ph2)-ybuf pw ph2];
xlimit=[-max(zd) max(zd)];
xlab='SiO2';
Pdat_rel_plot;

disp(['Sio: med, mad, w, zt dcrit zcrit =' num2str([med mad w zt dcrit zcrit])]);
%------------------------------------------------------
% Water Temperature
%------------------------------------------------------
dat=load('data/Corrected_welltemp_all.lldtz');
d=dat(:,3);;
zt=zt_temp;
Prc=Prc_welltemp;
med=-0.1396;  %this is for the whole dataset 
mad=1.9989;
med=median(d);
mad=1.482*median(abs(d-med));
dthresh=zt*mad+med;

dcrit=dcrit_welltemp;
d0=dcrit*[0:0.01:1.2]';  
z0=(d0-med)/mad;
z0=max([z0-zt zeros(size(z0))]')';

zcrit=(dcrit-med)/mad;
w=(log(Prc/(1-Prc))-w0)./(zcrit-zt); 
Pr=1./(1+exp(-w0-w.*z0));
pos1=[xl+pw+2*dy yt-2*((dy+ph)+(dy+ph2)+ybuf) pw ph];
pos2=[xl+pw+2*dy yt-2*((dy+ph)+(dy+ph2)+ybuf)-(dy+ph2)-ybuf pw ph2];
xlimit=[-max(z0) max(z0)+1];
xlab='(T_w_e_l_l-T_s_u_r_f) corrected for depth (^oC)';
Pdat_rel_plot

disp(['Well Temp: med, mad, w, zt, dcrit, zcrit=' num2str([med mad w zt dcrit zcrit])]);



