%========================================================================
% Show Pr vs data for different datasets
%========================================================================
clear;
prior=0.07; w0=log(prior)-log(1-prior)
Prc_grav=0.8; zcrit_grav=1.5;
Prc_rift=Prc_grav*0.75;  dcrit_rift=1.0;
Prc_vent=Prc_grav*0.56; dcrit_vent=1.0;
Prc_clmg=Prc_grav; dcrit_clmg=1000;  dthresh_clmg=15;
Prc_sio=0.75*Prc_grav; dcrit_sio=5.5; zt_sio=1;
Prc_sio=0.75*Prc_grav; dcrit_sio=500; zt_sio=1;
Prc_welltemp=Prc_grav*1.125; dcrit_welltemp=8; zt_temp=1;

bins=100;
nbins=100;

xl=0.11; yt=0.85;
ph=0.1; pw=0.28; dx=0.035; dy=0.04; ybuf=0.03;
textfac=1.1;
%------------------------------------------------------
% Gravity
%-----------------------------------------------------
Pheat_data_relations_gravity;

figure(1); clf;
subplot('Position',[xl yt pw ph]);
plot(a,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
percdcrit=sum(d>=dcrit)/length(d)*100; %text(textfac*dcrit,0.2,[num2str(percdcrit) '%']);
ylabel('Pr(H), Grav'); xlabel('RGA (mGal)'); axis tight; grid on;
axis([min(a) max(a) 0 1]);

nbins=100;
subplot('Position', [xl yt-(dy+ph) pw ph]);
nmax=max(hist(zd,nbins));
hist(zd,nbins); hold on;
xlabel('Standardized, transformed data')
ylabel('Number of data points');
plot(zcrit*[1 1],[0 nmax],'k--');
%text(textfac*zcrit,nmax,[num2str(zcrit)]);
xlim([min((a-meda)/mada) max((a-meda)/mada)]); 
grid on;

disp(['gravity: med, mad, w, dcrit, zcrit=' num2str([meda mada w dcrit zcrit])]);
%------------------------------------------------------
% Rift Zones
%-----------------------------------------------------
Pheat_data_relations_riftzones;

subplot('Position', [xl yt-2*(dy+ph)-ybuf pw ph]);
plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
%text(dcrit+4,0.8,['Prc/Prc_g_r_a_v=' num2str(Prc/Prc_grav)]);
ylabel('Pr(H), Prox. to Rift'); xlabel('Distance from Riftzone (km)'); axis tight; grid on;
set(gca,'XDIR','reverse');
axis([0 10 0 1]);


subplot('Position', [xl yt-3*(dy+ph)-ybuf pw ph]);
nmax=max(hist(zd,nbins));
hist(zd,nbins); hold on;
xlabel('Standardized, transformed data')
ylabel('Number of data points');
plot(zcrit*[1 1],[0 nmax],'k--');
%text(textfac*zcrit,nmax,[num2str(zcrit)]);
%axis tight
xlim([min(zd)-1 max(zd)+1]); 
grid on;
disp(['riftzones: med, mad, w, dcrit, zcrit=' num2str([meda mada w dcrit zcrit])]);

%------------------------------------------------------
% Vents;
%-----------------------------------------------------
Pheat_data_relations_vents

subplot('Position', [xl yt-4*(dy+ph)-2*ybuf pw ph]);
plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
ylabel('Pr(H), Prox. to Vent'); xlabel('Distance from Ventkm'); axis tight; grid on;
%text(dcrit+1,0.8,['Prc/Prc_g_r_a_v=' num2str(Prc/Prc_grav)]);
xlim([-0.05*R max(d0)])
set(gca,'XDIR','reverse');
%text(textfac*dcrit,0.2,['dcrit=' num2str(dcrit)],'Rotation',90);

subplot('Position', [xl yt-5*(dy+ph)-2*ybuf pw ph]);
nmax=max(hist(zd,nbins));
hist(zd,nbins); hold on;
xlabel('Standardized, transformed data')
ylabel('Number of data points');
plot(zcrit*[1 1],[0 nmax],'k--');
%text(textfac*zcrit,nmax,[num2str(zcrit)]);
%axis tight
xlim([min(zd)-1 max(zd)+1]); 
grid on;

disp(['vents: med, mad, w =' num2str([meda mada w])]);

%------------------------------------------------------
% Cl/Mg
%-----------------------------------------------------
Prc=Prc_clmg;
dat=load('data/Waterdatabaserev5_reformatted.txt');
ii=find(dat(:,7)>0 & dat(:,1)~=0);
d=log(dat(ii,7));
med=median(d); mad=1.482*median(abs(d-med));
dcrit=(dcrit_clmg);
dthresh=dthresh_clmg;
zt=(log(dthresh)-med)./mad;
zd=(d-med)./mad;

d0=dcrit*[0:0.01:1.5]';
z0=(log(d0)-med)./mad;
z0=max([z0-zt zeros(size(z0))]')';

zcrit=(log(dcrit)-med)/mad-zt;

w=(log(Prc/(1-Prc))-w0)./zcrit;
Pr=1./(1+exp(-w0-w.*z0));
wfinal(4)=w;

subplot('Position',[xl+(pw+2*dy) yt pw ph]);
plot(d0,Pr,'b-'); hold on; 
%ylabel('Pr(H), Cl/Mg'); xlabel('Cl/Mg'); axis tight; grid on;
text(0.1*dcrit,0.8,['Prc/Prc_g_r_a_v=' num2str(Prc/Prc_grav)]);
plot(dcrit*[1 1],[0 1],'k--');
plot(dthresh*[1 1],[0 1],'k--');
%text(textfac*dcrit,0.2,['dcrit=' num2str(dcrit)],'Rotation',90);
%text(textfac*dthresh,0.2,['dthresh=' num2str(dthresh)],'Rotation',90);


subplot('Position', [xl+(pw+2*dy) yt-(dy+ph) pw ph]);
nmax=max(hist(zd,nbins));
hist(zd,nbins); hold on;
xlabel('Standardized, transformed data')
ylabel('Number of data points');
plot(zcrit*[1 1],[0 nmax],'k--');
plot(zt*[1 1],[0 nmax],'k--');
%text(textfac*zcrit,nmax/2,['zcrit=' num2str(zcrit)], 'Rotation', 90);
%text(textfac*zt,nmax/2,['zt=' num2str(zt)],'Rotation',90);
xlim([-max(z0) max(z0)]); 
grid on;
disp(['Cl/Mg: med, mad, w, zt =' num2str([med mad w zt])]);
%------------------------------------------------------
% SiO2
%------------------------------------------------------
Prc=Prc_sio;
dat=load('data/SiO2_lnZ1_reformatted.txt');
aq=dat(:,1); lon=dat(:,2); lat=dat(:,3); sio=dat(:,4); lsio=dat(:,5); zd=dat(:,6);
med=3.84; mad=0.26;  %Means of Dave's table fpr APPROXIMATE case
med=median(lsio); mad=1.482*median(abs(lsio-med)); % APPROXIMATE 

zt=zt_sio;
dthresh=mad*(zt)+med;
dcrit=dcrit_sio;
zcrit=(log(dcrit)-med)./mad;

d0=[0:0.01:1.2]'*dcrit;
z0=(log(d0)-med)./mad;
z0=max([z0-zt zeros(size(z0))]')';

w=(log(Prc/(1-Prc))-w0)./(zcrit-zt); 
Pr=1./(1+exp(-w0-w.*z0));
wfinal(5)=w;

subplot('Position', [xl+pw+2*dy yt-2*(dy+ph)-ybuf pw ph]);
plot(d0,Pr,'b-'); hold on; 
plot(dcrit*[1 1],[0 1],'k--');
plot(dthresh*[1 1],[0 1],'k--');
ylabel('Pr(H), SiO2'); xlabel('SiO2 (ppm)'); axis tight; grid on;
%text(0.1*dcrit,0.8,['Prc/Prc_g_r_a_v=' num2str(Prc/Prc_grav)]);
%text(textfac*dcrit,0.2,['dcrit=' num2str(dcrit)],'Rotation',90);
%text(textfac*dthresh,0.2,['dthresh=' num2str(dthresh)],'Rotation',90);

subplot('Position', [xl+pw+2*dy yt-3*(dy+ph)-ybuf pw ph]);
nmax=max(hist(zd,nbins));
hist(zd,nbins); hold on;
xlabel('Standardized, transformed data')
ylabel('Number of data points');
plot(zcrit*[1 1],[0 nmax],'k--');
plot(zt*[1 1],[0 nmax],'k--');
%text(textfac*zcrit,nmax/2,['zcrit=' num2str(zcrit)], 'Rotation', 90);
%text(textfac*zt,nmax/2,['zt=' num2str(zt)],'Rotation',90);

%axis tight
xlim([-max(z0) max(z0)+1]); 
grid on;

disp(['Sio: med, mad, w, zt =' num2str([med mad w zt])]);
%------------------------------------------------------
% Water Temperature
%------------------------------------------------------
dat=load('data/Corrected_welltemp_all.lldtz');
d=dat(:,3);;
zt=zt_temp;
Prc=Prc_welltemp;
med=-0.1396;  %this is for the whole dataset 
mad=1.9989;
med=median(d);
mad=1.482*median(abs(d-med));
dthresh=zt*mad+med;

dcrit=dcrit_welltemp;
d0=dcrit*[0:0.01:1.5]';  
z0=(d0-med)/mad;
z0=max([z0-zt zeros(size(z0))]')';

zcrit=(dcrit-med)/mad;
w=(log(Prc/(1-Prc))-w0)./(zcrit-zt); 
Pr=1./(1+exp(-w0-w.*z0));
wfinal(6)=w;

subplot('Position', [xl+pw+2*dy yt-4*(dy+ph)-2*ybuf pw ph]);
plot(d0,Pr,'b-'); hold on;
ylabel('Pr(H), Well Temp.'); xlabel('(T_w_e_l_l-T_s_u_r_f) corrected for depth (^oC)'); axis tight; grid on;
%text(0.1*dcrit,0.8,['Prc/Prc_g_r_a_v=' num2str(Prc/Prc_grav)]);
plot(dcrit*[1 1],[0 1],'k--');
plot(dthresh*[1 1],[0 1],'k--');
%text(textfac*dcrit,0.2,['dcrit=' num2str(dcrit)],'Rotation',90);
%text(textfac*dthresh,0.2,['dthresh=' num2str(dthresh)],'Rotation',90);


subplot('Position', [xl+pw+2*dy yt-5*(dy+ph)-2*ybuf pw ph]);
nmax=max(hist(zd,nbins));
hist(zd,nbins); hold on;
xlabel('Standardized, transformed data')
ylabel('Number of data points');
plot(zcrit*[1 1],[0 nmax],'k--');
plot(zt*[1 1],[0 nmax],'k--');
%text(textfac*zcrit,nmax/2,['zcrit=' num2str(zcrit)], 'Rotation', 90);
%text(textfac*zt,nmax/2,['zt=' num2str(zt)],'Rotation',90);
xlim([-max(z0) max(z0)+1]); 
grid on;

disp(['med, mad, w, zt, well temp=' num2str([med mad w zt])]);

if(0);
subplot(221)
hist(d,bins); hold on;
plot([median(d) median(d)], 3/bins*length(d)*[0 1],'k-','LineWidth',2);
plot([dcrit dcrit],3/bins*length(d)*[0 1],'k--','LineWidth',2);
xlabel('Data');
grid on;
end;


