%========================================================================
% Show Pr vs data for different datasets
%========================================================================
clear;
prior=0.1; w0=log(prior)-log(1-prior);
Prc_grav=0.8; acrit_grav=1.5;
Prc_rift=Prc_grav*0.75;  dcrit_rift=1.0;
Prc_vent=Prc_grav*0.56; dcrit_vent=1.0;
Prc_clmg=Prc_grav; dcrit_clmg=1000;  dthresh_clmg=15;
Prc_sio=0.75*Prc_grav; dcrit_sio=5.5; zt_sio=1;
Prc_sio=0.75*Prc_grav; dcrit_sio=500; zt_sio=1;
Prc_welltemp=Prc_grav*1.125; dcrit_welltemp=8; zt_temp=1;
fact=1;

bins=100;

%------------------------------------------------------
% Gravity
%-----------------------------------------------------
Prc=Prc_grav;
file=load('../data/residual_subaerial.llre');
d=file(:,3);
med=median(d); mad=1.482*median(abs(d-med));
acrit=acrit_grav;
dcrit=med+acrit*mad;
acrit=(dcrit-med)/mad;
d0=dcrit.*[0:0.01:1.5]'; z0=(d0-med)/mad;
a0=z0;
w=(log(Prc/(1-Prc))-w0)./acrit; w=w*fact; Pr=1./(1+exp(-w0-w.*a0));
wfinal=w;

figure(1); clf;
subplot(321);
plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
percdcrit=sum(d>=dcrit)/length(d)*100; text(1.03*dcrit,0.2,[num2str(percdcrit) '%']);

ylabel('Pr(H), Grav'); xlabel('RGA (mGal)'); axis tight; grid on;
disp(['med, mad, w gravity=' num2str([med mad w])]);

%------------------------------------------------------
% Rift Zones
%-----------------------------------------------------
Prc=Prc_rift;
dcrit=dcrit_rift;
d0=[0:0.01:1]'; 
d0=[-1.5:0.01:1]';
acrit=dcrit;
%a0=min([d0 ones(size(d0))]')';
a0=d0;
w=(log(Prc/(1-Prc))-w0)./acrit; w=w*fact; Pr=1./(1+exp(-w0-w.*a0));
wfinal(2)=w;

subplot(323);
plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
text(-(1.0)*dcrit,0.8,['Prc/Prc_g_r_a_v=' num2str(Prc/Prc_grav)]);
ylabel('Pr(H), Prox. to Rift'); xlabel('(5 km-Distance)/5 km'); axis tight; grid on;
xlim([-1.5 1].*dcrit);
disp(['med, mad, w rifts=' num2str([999 999 w])]);

%------------------------------------------------------
% Vents;
%-----------------------------------------------------
Prc=Prc_vent;
dcrit=dcrit_vent;
d0=[0:0.01:1]'; 
a0=min([d0 ones(size(d0))]')';
acrit=dcrit;
w=(log(Prc/(1-Prc))-w0)./acrit; w=w*fact; Pr=1./(1+exp(-w0-w.*a0));
wfinal(3)=w;

subplot(325);
plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
ylabel('Pr(H), Prox. to Vent'); xlabel('(1.5km-Distance)/1.5km'); axis tight; grid on;
xlim([0 1.5*dcrit]);
text(0.1*dcrit,0.8,['Prc/Prc_g_r_a_v=' num2str(Prc/Prc_grav)]);
disp(['med, mad, w vents=' num2str([999 999 w])]);
%------------------------------------------------------
% Cl/Mg
%-----------------------------------------------------
Prc=Prc_clmg;
dat=load('../data/Waterdatabaserev5_reformatted.txt');
ii=find(dat(:,7)>0 & dat(:,1)~=0);
d=log(dat(ii,7));
med=median(d); mad=median(abs(d-med));
dcrit=(dcrit_clmg);
dthresh=dthresh_clmg;

d0=dcrit*[0:0.01:1.5]';
z=(log(d0)-med)./mad;
zt=(log(dthresh)-med)./mad;
a0=max([z-zt zeros(size(z))]')';
acrit=(log(dcrit)-med)/mad-zt;

w=(log(Prc/(1-Prc))-w0)./acrit; w=w*fact; Pr=1./(1+exp(-w0-w.*a0));
wfinal(4)=w;

subplot(322);
plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
ylabel('Pr(H), Cl/Mg'); xlabel('Cl/Mg'); axis tight; grid on;
text(0.1*dcrit,0.8,['Prc/Prc_g_r_a_v=' num2str(Prc/Prc_grav)]);
percdcrit=sum(exp(d)>=dcrit)/length(d)*100; text(1.03*dcrit,0.2,[num2str(percdcrit) '%']);
disp(['med, mad, w, zt Cl/Mg=' num2str([med mad w zt])]);

%------------------------------------------------------
% SiO2
%------------------------------------------------------
Prc=Prc_sio;
dat=load('../data/SiO2_lnZ1_reformatted.txt');
aq=dat(:,1); lon=dat(:,2); lat=dat(:,3); sio=dat(:,4); lsio=dat(:,5); zd=dat(:,6);
med=3.84; mad=0.26;  %Means of Dave's table fpr APPROXIMATE case
zt=zt_sio;
dcrit=dcrit_sio;
zcrit=(log(dcrit)-med)/mad;

d0=[0:0.01:1.5]'*dcrit;

a0=(log(d0)-med)/mad-zt;
a0=max([a0 zeros(size(a0))]')';
acrit=zcrit-zt;

w=(log(Prc/(1-Prc))-w0)./acrit; Pr=1./(1+exp(-w0-w.*a0));
wfinal(5)=w;

subplot(324);
plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
%plot(a0,Pr,'b'); hold on; plot(dcrit*[1 1],[0 1],'k--');
ylabel('Pr(H), SiO2'); xlabel('SiO2 (ppm)'); axis tight; grid on;
text(0.1*dcrit,0.8,['Prc/Prc_g_r_a_v=' num2str(Prc/Prc_grav)]);
percdcrit=sum(zd>=zcrit)/length(zd)*100; text(1.03*dcrit,0.2,[num2str(percdcrit) '%']);
disp(['med, mad, w, zt, Sio=' num2str([med mad w zt])]);
%------------------------------------------------------
% Water Temperature
%------------------------------------------------------
dat=load('../data/Corrected_welltemp.lldtz');
d=dat(:,3);;
zt=zt_temp;
Prc=Prc_welltemp;
med=-0.1396;  %this is for the whole dataset whereas whats in the above file is only > 0
mad=1.9989;

dcrit=dcrit_welltemp;
d0=dcrit*[0:0.01:1.5]';  
a0=(d0-med)/mad-zt;

a0=max([a0 zeros(size(a0))]')';
acrit=(dcrit-med)/mad-zt;
w=(log(Prc/(1-Prc))-w0)./acrit; w=w*fact; Pr=1./(1+exp(-w0-w.*a0));
wfinal(6)=w;

subplot(326);
plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
ylabel('Pr(H), Well Temp.'); xlabel('(T_w_e_l_l-T_s_u_r_f) corrected for depth (^oC)'); axis tight; grid on;
text(0.1*dcrit,0.8,['Prc/Prc_g_r_a_v=' num2str(Prc/Prc_grav)]);
percdcrit=sum(d>=dcrit)/length(d)*100; text(1.03*dcrit,0.2,[num2str(percdcrit) '%']);
disp(['med, mad, w, zt, well temp=' num2str([med mad w zt])]);

if(0);
subplot(221)
hist(d,bins); hold on;
plot([median(d) median(d)], 3/bins*length(d)*[0 1],'k-','LineWidth',2);
plot([dcrit dcrit],3/bins*length(d)*[0 1],'k--','LineWidth',2);
xlabel('Data');
grid on;
end;


