%========================================================================
% Computes weight for resisitivity
%========================================================================
clear;
prior=0.83; 
Prc_mt=0.995;
nbins=100;
w0=log(prior)-log(1-prior)

xl=0.11; 
ph=0.08; pw=0.28; dx=0.035; dy=0.06; ybuf=0.03;
yt=0.5; pw=0.4; ph=0.25; ph2=0.08; dy=0.1; ybuf=0.01;
textfac=1.1;
xrev=0;

%------------------------------------------------------------------------
% get Saddle station locations and corresponding along-track
%  distance from west side
%------------------------------------------------------------------------
dat=load('../data/Saddle_MT.txt');
x1=dat(:,1); y1=dat(:,2); el=dat(:,3);dmin=dat(:,4); dmax=dat(:,5);
dalong=zeros(size(x1));
dalong(1)=500;
dalong(2:end)=dalong(1)+cumsum(sqrt((x1(2:end)-x1(1:end-1)).^2+(y1(2:end)-y1(1:end-1)).^2));

%-------------------------------------------------------------------------
% Now load model and interpolate data at station positions along track
%------------------------------------------------------------------------

dat2=load('../data/MT_resistivities.xzr');
x=dat2(:,1); z=dat2(:,2); 
nz=22; nx=length(x)/nz;
X=reshape(x,nz,nx); Z=reshape(z,nz,nx); rho=reshape(dat2(:,3),nz,nx);
zrange=Z(find(Z(:,1)<=500 & Z(:,1)>0),1);
[xprof zprof]=meshgrid(dalong,zrange);
rhogrid=interp2(X,Z,rho,xprof,zprof);

i1=min(find(X(1,:)>=dalong(1))); i2=max(find(X(1,:)<=dalong(end)))
elgrid=interp1(dalong,el,X(1,i1:i2));

figure(2); clf;
n=1;
for i=i1:i2;
  ii=find(Z(:,i)>elgrid(n));
  rho(ii,i)=-10;
  n=n+1;
end;

subplot(211);
contourf(X,Z,log10(rho)); colorbar; hold on;
plot(X(1,i1:i2),elgrid,'w');
subplot(413);
contourf(xprof,zprof,rhogrid); colorbar
rhomean=mean(rhogrid)';



figure(1); clf;
%-------------------------------------------------------------------------
ilog=0;

[lat,lon]=u2d(dat(:,1),dat(:,2),5);
rho=rho(:,i1:i2);

d=rho(find(rho>0));

if (ilog); 
    dcrit=log(3);
    d0=log([1:1:300])'; %range of zero-age gravity (also full range of transformed data)
    d=log(d);
else
    dcrit=30;
    d0=[10:10:4000]';
end;

Prc=Prc_mt;
med=median(d); mad=1.482*median(abs(d-med));
med=1.8*med;
zd=(d-med)./mad;

zcrit=(dcrit-med)/mad;
dthresh=0;
zt=0;

z0=(d0-med)/mad;           %z of transformed data (all ages)
w=(log(Prc/(1-Prc))-w0)./zcrit;
Pr=1./(1+exp(-w0-w.*z0));

pos1=[xl yt pw ph]; 
pos2=[xl yt-(dy+ph2) pw ph2];
xlab='Ohm-m'; 
xlimit=[min(z0) max(z0)];
if (ilog); 
    d0=exp(d0);
end;

Pdat_rel_plot;

disp(['MT: med, mad, w, dcrit, zcrit=' num2str([med mad w dcrit zcrit])])

