%========================================================================
% Show Pr(Perm) vs data for different datasets
%========================================================================
clear;
prior=0.83; 
prior=0.78;
w0=log(prior)-log(1-prior);
Prc_wtable=0.95;  dthresh_wtable=0; dcrit_wtable=1000; zcrit_wtable=1.5;
Prc_recharge=0.5*(Prc_wtable-prior)+prior; dthresh_recharge=0; dcrit_recharge=1.5; zcrit_recharge=1.5;
bins=100;
xl=0.2; yt=0.68
wid=0.4; ht=0.3; ybuf=0.05; ht2=0.08;
nbins=100;
%------------------------------------------------------
% Water Table
%-----------------------------------------------------
iloghead=1;
Prc=Prc_wtable;
if (iloghead); 
    dcrit=log(dcrit_wtable);
else;
    dcrit=dcrit_wtable;
end

% !awk '{print $1, $2, $3}' data/BI_watertable.llhed >! data/watertable_allislands.llh
% !awk '{if ($3 >-300) print $1, $2, $3}' data/Water_table_Kauai_through_Lanai.txt  >> data/watertable_allislands.llh
!grd2xyz BI/BI_head.grd >! data/watertable_allislands.llh
!grd2xyz MN/MN_head.grd >> data/watertable_allislands.llh
!grd2xyz Oahu/Oahu_head.grd >> data/watertable_allislands.llh
!grd2xyz Kauai/Kauai_head.grd >> data/watertable_allislands.llh


dat=load('data/watertable_allislands.llh');
ii=find(dat(:,3) > 0);
if (iloghead)
    ii=find(dat(:,3) > 0);
    d=log(dat(ii,3)); 
else
    d=dat(ii,3);
end;
med=median(d); mad=1.482*median(abs(d-med));
zd=(d-med)/mad;
zcrit=(dcrit-med)/mad;
zcrit=zcrit_wtable;
dcrit=zcrit*mad+med;

d0=[min(d):0.01:1.1*dcrit]'; 
z0=(d0-med)/mad;
w=(log(Prc/(1-Prc))-w0)./zcrit; 
Pr=1./(1+exp(-w0-w.*z0));
wfinal=w;

figure(1); clf;
subplot('position',[xl yt wid ht]);
if (iloghead)
    plot(exp(d0),Pr,'b-'); hold on; 
    plot(exp(dcrit)*[1 1],[0 1],'k--');
else
   plot((d0),Pr,'b-'); hold on; 
   plot(dcrit*[1 1],[0 1],'k--');
end
set(gca,'Ytick',[0:0.1:1]);
ylabel('Pr(F), W. Table'); 
xlabel('water table elevation(m)');
axis tight; grid on;

subplot('position',[xl yt-ht2-ybuf wid ht2]);
nmax=max(hist(zd,nbins));
hist(zd,nbins); hold on;
ylabel('Number of data points');
plot(zcrit*[1 1],[0 1.1*nmax],'k--');
text(1.03*zcrit,nmax,[num2str(zcrit)]);
xlim([min(zd) max(zd)]); 
xlabel('Standardized')
grid on;


disp(['Water table: med, mad, w dcrit zcrit =' num2str([med mad w exp(dcrit) zcrit])]);
%------------------------------------------------------
% Recharge
%-----------------------------------------------------
Prc=Prc_recharge;
dthresh=dthresh_recharge;
dcrit=dcrit_recharge;
inyr=2.54/365.25;
ilogrech=1;

% dat1=load('data/BI_Recharge_DD_WGS_84.txt');
% dat2=load('data/kauai_recharge_points_WGS84.txt');
% dat3=load('data/Oahu_Recharge_DD_WGS_84.txt');
% dat4=load('data/Maui_Recharge_DD_WGS_84.txt');
% dat5=load('data/lanai_recharge_points_WGS84.txt');
% dat6=load('data/molokai_recharge_points_WGS84.txt');
% d=[dat1(:,3)*100; dat2(:,3)*100; dat3(:,3)*inyr; dat4(:,3)*inyr; dat5(:,3)*100; dat5(:,3)*100;];
!grd2xyz BI/BI_recharge.grd >! data/recharge_all_islands.llr
!grd2xyz MN/MN_recharge.grd >> data/recharge_all_islands.llr
!grd2xyz Oahu/Oahu_recharge.grd >> data/recharge_all_islands.llr
!grd2xyz Kauai/Kauai_recharge.grd >> data/recharge_all_islands.llr

dat=load('data/recharge_all_islands.llr');
ii=find(dat(:,3)>0);
d=dat(ii,3);
if (ilogrech)
    dsort=unique(sort(d));
    dmin=dsort(1)*dsort(1)/dsort(2);
    ii=find(d<=0);
    d(ii)=dmin;
    d=log(d);
    dcrit=log(dcrit);
end;
med=median(d); mad=1.482*median(abs(d-med));
zd=(d-med)/mad;

zcrit=(dcrit-med)/mad;
zcrit=zcrit_recharge;
dcrit=zcrit*mad+med;

d0=[min(d):0.01:dcrit+abs(0.2*dcrit)]'; 
z0=(d0-med)/mad;
w=(log(Prc/(1-Prc))-w0)./zcrit; 
Pr=1./(1+exp(-w0-w.*z0));
wfinal(2)=w;

subplot('position',[xl yt-(ht+ybuf)-(ht2+ybuf)-ybuf/3 wid ht]);
if (ilogrech)
    plot(exp(d0),Pr,'b'); hold on; 
    plot(exp(dcrit)*[1 1],[0 1],'k--')
else;
    plot(d0,Pr,'b-'); hold on; 
    plot(dcrit*[1 1],[0 1],'k--');
end;
ylabel('Pr(F), Recharge'); xlabel('recharge (cm/day)');axis tight; grid on;
set(gca,'Ytick',[0:0.1:1]);

subplot('position',[xl yt-(ht+ybuf)-(ht2+ybuf)-(ht2+ybuf)-ybuf/3 wid ht2]);
nmax=max(hist(zd,nbins));
hist(zd,nbins); hold on;
ylabel('Number of data points');
plot(zcrit*[1 1],[0 nmax],'k--');
text(1.03*zcrit,nmax,[num2str(zcrit)]);
xlim([min(zd) max(zd)]); 
xlabel('Standardized')
grid on;

disp(['Recharge: med, mad, w dcrit zcrit =' num2str([med mad w exp(dcrit) zcrit])]);
