%========================================================================
% Show Pr(Perm) vs data for different datasets
%========================================================================
clear;
iwater=0;
prior=0.14; 
%prior=0.16; 
w0=log(prior)-log(1-prior);
Prc_rift=0.8;  dcrit_rift=1.0;
Prc_grav=Prc_rift*0.75; zcrit_grav=1.5;
Prc_div=Prc_rift; zcrit_div=1.5;  dthresh_div=0; dnull_div=0.0;
Prc_seis=Prc_rift; zcrit_seis=1.5; dthresh_seis=0;

bins=100;
wid=0.4; ht=0.28; ht2=0.1; xbuf=0.05; ybuf=0.05; ybuf2=0.02; x1=0.1; y1=0.69; fs=9;
xrev=0;
figure(1); clf;
%------------------------------------------------------
% Gravity
%-----------------------------------------------------
nbins=bins;
Prc=Prc_grav;
file=load('data/residual_subaerial.llre');
d=file(:,3);
med=median(d); mad=1.482*median(abs(d-med));
zd=(d-med)./mad;

zcrit=zcrit_grav;       %Zero-age value
dcrit=med+zcrit*mad;  %Data value set based on zero-age data
dthresh=0;
zt=0;

d0=dcrit.*[-0.75:0.01:1.5]'; %range of zero-age gravity (also full range of transformed data)
z0=(d0-med)/mad;           %z of transformed data (all ages)
w=(log(Prc/(1-Prc))-w0)./zcrit;
Pr=1./(1+exp(-w0-w.*z0));

pos1=[x1 y1 wid ht]; 
pos2=[x1 y1-(ht2+ybuf) wid ht2]; 
xlab='RGA (mGal)';
xlimit=[min(z0) max(z0)];

Pdat_rel_plot;

disp(['gravity: med, mad, w, dcrit, zcrit=' num2str([med mad w dcrit zcrit])]);
%------------------------------------------------------
% Rift Zones
%-----------------------------------------------------
Prc=Prc_rift;
dmin=1e-10;
R=1.5;
%if (exist('data/all_islands_riftzones_prox.llr','var')==0);
format long
!gmtset D_FORMAT %.6f
!grd2xyz BI/prox_riftfaults_negsubmarine.grd -S >! junk
!grd2xyz MN/prox_riftfaults_negsubmarine.grd >> junk
!grd2xyz Oahu/prox_riftfaults_negsubmarine.grd >> junk
!grd2xyz Kauai/prox_riftfaults_negsubmarine.grd >> junk
!awk '{if ($3 > 0) print $1, $2, $3}' junk >! data/all_islands_riftfaults_prox.llr
%end;

dat=load('data/all_islands_riftfaults_prox.llr');
d=exp(-dat(:,3)./R); 
med=median(d); mad=1.482*median(abs(d-med));
zd=(d-med)./mad;
zt=0;
dthresh=0;
xrev=1;

d0=[0.0:0.1:10]; dcrit=0;
a0=exp(-d0./R);
acrit=exp(-dcrit./R);
zcrit=(acrit-med)./mad;
z0=(a0-med)./mad;
w=(log(Prc/(1-Prc))-w0)./zcrit; %Solve for weight based on zcrit 
Pr=1./(1+exp(-w0-w.*z0));

pos1=[x1 y1-(ht+ht2+2*ybuf)-ybuf2 wid ht];
pos2=[x1 y1-(ht+2*ht2+3*ybuf)-ybuf2 wid ht2];
xlab=('Distance from Rift & Fault (km)');
xlimit=[min(zd)-0.1 max(zd)+0.1];
Pdat_rel_plot;
disp(['riftzones: med, mad, w, dcrit, zcrit=' num2str([med mad w dcrit zcrit])]);
xrev=0;

%------------------------------------------------------
% Divergence
%-----------------------------------------------------
!grd2xyz  BI/divergence_negsubmarine.grd >! BI/divergence_negsubmarine.lld;
ilogdiv=0;  
Prc=Prc_div;

dat=load('BI/divergence_negsubmarine.lld'); 
%ii=find(dat(:,3)>0);
%ii=find(dat(:,3)<1e10);
%%dd=abs(dat(ii,3));   %I use the absolute value of divergence!
ii=find(dat(:,3)>-5);  %everything underwater is -O(1e12)
dd=dat(ii,3); 
lon=dat(ii,1); lat=dat(ii,2);
%jj=find(dd>dnull); d=dd(jj); lon=lon(jj); lat=lat(jj);
d=dd; 
%lat=lat(abs(d)>dnull); lon=lon(abs(d)>dnull);

if (ilogdiv); d=log(d); end;
med=median(d); mad=1.482*median(abs(d-med));
zt=0;
zd=(d-med)/mad;
zcrit=zcrit_div;
dcrit=zcrit*mad+med;

if (ilogdiv); dcrit=log(dcrit); end;

d0=dcrit*[-0.5:0.01:1.2]'; 
if (ilogdiv); 
    d0=[-5:0.1:1.2]'*dcrit; 
end;
z0=((d0-med)/mad-zt);
zcrit=((dcrit-med)/mad-zt);
w=(log(Prc/(1-Prc))-w0)./zcrit; 
Pr=1./(1+exp(-w0-w.*z0));
wfinal(3)=w;

subplot('position',[x1+wid+xbuf y1 wid ht]);
if (ilogdiv);
    plot(exp(d0),Pr,'b-'); hold on; plot(exp(dcrit)*[1 1],[0 1],'k--');
else
    plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
end
xlabel('Divergence');
set(gca,'Ytick',[0:0.1:1]);
axis tight; grid on;
xlim([-0.5 1.2*dcrit]);

subplot('position',[x1+wid+xbuf y1-(ht2+ybuf) wid ht2]);
nmax=max(hist(zd,nbins));
hist(zd,100); hold on;
plot(zcrit*[1 1],[0 nmax],'k--');
xlabel('standandardized, transformed, z*');
axis tight
grid on;

disp(['divergence: med, mad, w, dcrit zcrit =' num2str([med mad w dcrit zcrit])]);
%------------------------------------------------------
% seismicity
%----------------------------------------------------
ilogseis=1;
!grd2xyz  BI/seismicity_negsubmarine.grd >! BI/seismicity_negsubmarine.lls;
dat=load('BI/seismicity_negsubmarine.lls'); 
ii=find(dat(:,3)>0);
d=(dat(ii,3));
if (ilogseis); d=log(d); end;
Prc=Prc_seis;
med=median(d); mad=1.482*median(abs(d-med));
zd=(d-med)/mad;
zcrit=zcrit_seis;
dcrit=exp(mad.*zcrit+med);

d0=[0:0.01:1.2]*dcrit;
z0=(log(d0)-med)/mad;

w=(log(Prc/(1-Prc))-w0)./zcrit; 
Pr=1./(1+exp(-w0-w.*z0));
wfinal(4)=w;

pos1=[x1+wid+xbuf y1-(ht+ht2+2*ybuf)-ybuf2 wid ht];
pos2=[x1+wid+xbuf y1-(ht+2*ht2+3*ybuf)-ybuf2 wid ht2];
subplot('position',pos1);
plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
xlabel('Seismicity, events/km^2/yr');
set(gca,'Ytick',[0:0.1:1]);
axis tight; grid on;

subplot('position',pos2);
nmax=max(hist(zd,nbins));
hist(zd,100); hold on;
plot(zcrit*[1 1],[0 nmax],'k--');
grid on;
xlabel('standandardized, transformed, z*');

disp(['seismicity: med, mad, w, dcrit zcrit =' num2str([med mad w dcrit zcrit])]);

w0

