%========================================================================
% Show Pr(Perm) vs data for different datasets
%========================================================================
clear;
iwater=0;
prior=0.01; w0=log(prior)-log(1-prior);
Prc_rift=0.8;  dcrit_rift=1.0;
Prc_grav=Prc_rift*0.75; acrit_grav=1.5;
Prc_div=Prc_rift; dcrit_div=3.0;  dthresh_div=0; dnull_div=0.3;
Prc_seis=Prc_rift; dcrit_seis=1.0; dthresh_seis=0;
Prc_clmg=Prc_rift; dcrit_clmg=1000;  dthresh_clmg=15;
Prc_sio=0.75*Prc_rift; dcrit_sio=500; zt_sio=1;
Prc_welltemp=Prc_rift*1.125; dcrit_welltemp=8; zt_temp=1;

bins=100;
wid=0.4; ht=0.12; ybuf=0.01; ybuf2=0.06; x1=0.1; y1=0.84; fs=9;
%------------------------------------------------------
% Gravity
%-----------------------------------------------------
Prc=Prc_grav;
file=load('../data/residual_subaerial.llre');
d=file(:,3);
med=median(d); mad=1.482*median(abs(d-med));
acrit=acrit_grav;
dcrit=med+acrit*mad;
acrit=(dcrit-med)/mad;
d0=dcrit.*[0:0.01:1.5]'; z0=(d0-med)/mad;
a0=z0;
w=(log(Prc/(1-Prc))-w0)./acrit; Pr=1./(1+exp(-w0-w.*a0));
wfinal=w;

figure(1); clf;
subplot('position',[x1 y1 wid ht]);
plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
percdcrit=sum(d>=dcrit)/length(d)*100; text(1.03*dcrit,0.2,[num2str(percdcrit) '%']);
text(0.1*dcrit,0.8,['Prc/Prc_r_i_f_t=' num2str(Prc/Prc_rift)]);
text(0.5*dcrit,1.25, ['RGA (mGal)'],'FontSize',fs);
set(gca,'XaxisLocation','top','FontSize',fs) 
axis tight; grid on;

subplot('position',[x1 y1-(ht+ybuf) wid ht]);
plot(a0,Pr,'b-'); hold on; plot(acrit*[1 1],[0 1],'k--');
set(gca,'FontSize',fs)
text(-0.8*acrit, 0.55,'Pr(H), Grav','Rotation',90); axis tight; grid on;
disp(['med, mad, w gravity=' num2str([med mad w])]);
%------------------------------------------------------
% Rift Zones
%-----------------------------------------------------
Prc=Prc_rift;
dcrit=dcrit_rift;
d0=dcrit.*[0:0.01:1]'; 
acrit=dcrit;
a0=min([d0 ones(size(d0))]')';
w=(log(Prc/(1-Prc))-w0)./acrit; Pr=1./(1+exp(-w0-w.*a0));
wfinal(2)=w;

subplot('position',[x1 y1-2*(ht+ybuf)-ybuf2 wid ht]);
plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
text(0.1*dcrit,0.8,['Prc/Prc_r_i_f_t=' num2str(Prc/Prc_rift)]);
text(0.4*dcrit,1.25, ['(5km-Distance)/5km'],'FontSize',fs);
set(gca,'XaxisLocation','top','FontSize',fs)
axis tight; grid on;
xlim([0 1.5*dcrit]);

subplot('position',[x1 y1-3*(ht+ybuf)-ybuf2 wid ht]);
plot(a0,Pr,'b-'); hold on; plot(acrit*[1 1],[0 1],'k--');
set(gca,'FontSize',fs)
text(-0.15*acrit, 0.55, 'Pr(H), Prox. to Rift','Rotation',90); xlim([0 1.5*acrit]);
grid on;
disp(['med, mad, w rifts=' num2str([999 999 w])]);

%------------------------------------------------------
% Divergence
%-----------------------------------------------------
%!grd2xyz  divergence.grd >! divergence.lld;
Prc=Prc_div;
dcrit=dcrit_div;
dthresh=dthresh_div;
dnull=dnull_div;

dat=load('divergence.lld'); d=dat(:,3);
d=d(abs(d)>dnull);
med=median(d); mad=median(abs(d-med));
zt=(dthresh-med)/mad;

d0=dcrit*[0:0.01:1.5]'; 
a0=abs((d0-med)/mad-zt);
acrit=abs((dcrit-med)/mad-zt);
w=(log(Prc/(1-Prc))-w0)./acrit; Pr=1./(1+exp(-w0-w.*a0));
wfinal(3)=w;

subplot('position',[x1+wid+1.35*ybuf2 y1 wid ht]);
plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
text(0.7*dcrit,1.25, ['1/Myr'],'FontSize',fs);
set(gca,'XaxisLocation','top','FontSize',fs)
axis tight; grid on;
xlim([0 1.5*dcrit]);
text(0.1*dcrit,0.8,['Prc/Prc_r_i_f_t=' num2str(Prc/Prc_rift)]);
percdcrit=sum(d>=dcrit)/length(d)*100; text(1.03*dcrit,0.2,[num2str(percdcrit) '%']);

subplot('position',[x1+wid+1.35*ybuf2 y1-(ht+ybuf) wid ht]);
plot(a0,Pr,'b-'); hold on; plot(acrit*[1 1],[0 1],'k--');
set(gca,'FontSize',fs)
xlim([0 1.5*acrit]); grid on;
text(-0.15*acrit, 0.55, 'Pr(H), Divergence','Rotation',90); 
disp(['med, mad, w, zt divergence=' num2str([med mad w zt])]);

%------------------------------------------------------
% seismicity
%----------------------------------------------------
dat=load('seismicity.xyf'); d=(dat(:,3));
Prc=Prc_seis;
dcrit=dcrit_seis;
dthresh=dthresh_seis;

d0=dcrit.*[0:0.01:1.5]'; 
med=median(d); mad=median(abs(d-med));
zt=(dthresh-med)/mad;
a0=(d0-med)/mad-zt;
acrit=(dcrit-med)/mad-zt;

w=(log(Prc/(1-Prc))-w0)./acrit; Pr=1./(1+exp(-w0-w.*a0));
wfinal(4)=w;

subplot('position',[x1+wid+1.35*ybuf2 y1-2*(ht+ybuf)-ybuf2 wid ht]);
plot((d0),Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
text(0.5*dcrit,1.25, ['events/km^2/yr'],'FontSize',fs);
set(gca,'XaxisLocation','top','FontSize',fs)
axis tight; grid on;
text(0.1*dcrit,0.8,['Prc/Prc_r_i_f_t=' num2str(Prc/Prc_rift)]);
percdcrit=sum(d>=(dcrit))/length(d)*100; text(1.03*dcrit,0.5,[num2str(percdcrit) '%']);


subplot('position',[x1+wid+1.35*ybuf2 y1-3*(ht+ybuf)-ybuf2 wid ht]);
plot(a0,Pr,'b-'); hold on; plot(acrit*[1 1],[0 1],'k--');
set(gca,'FontSize',fs);
text(-0.15*acrit, 0.55, 'Pr(H), Seismicity','Rotation',90);
grid on; axis tight
disp(['med, mad, w, zt seismicity=' num2str([med mad w zt])]);

if (iwater)
%------------------------------------------------------
% Cl/Mg
%-----------------------------------------------------
Prc=Prc_clmg;
dat=load('../data/Waterdatabaserev5_reformatted.txt');
ii=find(dat(:,7)>0 & dat(:,1)~=0);
d=log(dat(ii,7));
med=median(d); mad=median(abs(d-med));
dcrit=(dcrit_clmg);
dthresh=dthresh_clmg;

d0=dcrit*[0:0.01:1.5]';
z=(log(d0)-med)./mad;
zt=(log(dthresh)-med)./mad;
a0=max([z-zt zeros(size(z))]')';
acrit=(log(dcrit)-med)/mad-zt;

w=(log(Prc/(1-Prc))-w0)./acrit; Pr=1./(1+exp(-w0-w.*a0));

figure(2); clf;
subplot('position',[x1 y1 wid ht]);
plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
percdcrit=sum(d>=dcrit)/length(d)*100; text(1.03*dcrit,0.2,[num2str(percdcrit) '%']);
text(0.1*dcrit,0.8,['Prc/Prc_r_i_f_t=' num2str(Prc/Prc_rift)]);
text(0.5*dcrit,1.25, ['Cl/Mg'],'FontSize',fs);
set(gca,'XaxisLocation','top','FontSize',fs) 
axis tight; grid on;

subplot('position',[x1 y1-(ht+ybuf) wid ht]);
plot(a0,Pr,'b-'); hold on; plot(acrit*[1 1],[0 1],'k--');
set(gca,'FontSize',fs)
text(-0.15*acrit, 0.55,'Pr(P), Cl/Mg','Rotation',90); axis tight; grid on;
disp(['med, mad, w Cl/Mg=' num2str([med mad w])]);
xlim([0 1.5*acrit]);

%------------------------------------------------------
% SiO2
%------------------------------------------------------
Prc=Prc_sio;
dat=load('../data/SiO2_lnZ1_reformatted.txt');
aq=dat(:,1); lon=dat(:,2); lat=dat(:,3); sio=dat(:,4); lsio=dat(:,5); zd=dat(:,6);
med=3.84; mad=0.26;  %Means of Dave's table fpr APPROXIMATE case
zt=zt_sio;
dcrit=dcrit_sio;
zcrit=(log(dcrit)-med)/mad;

d0=[0:0.01:1.5]'*dcrit;

a0=(log(d0)-med)/mad-zt;
a0=max([a0 zeros(size(a0))]')';
acrit=zcrit-zt;

w=(log(Prc/(1-Prc))-w0)./acrit; Pr=1./(1+exp(-w0-w.*a0));


subplot('position',[x1 y1-2*(ht+ybuf)-ybuf2 wid ht]);
plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
text(0.1*dcrit,0.8,['Prc/Prc_r_i_f_t=' num2str(Prc/Prc_rift)]);
text(0.4*dcrit,1.25, ['SiO2 (ppm)'],'FontSize',fs);
set(gca,'XaxisLocation','top','FontSize',fs)
axis tight; grid on;
xlim([0 1.5*dcrit]);

subplot('position',[x1 y1-3*(ht+ybuf)-ybuf2 wid ht]);
plot(a0,Pr,'b-'); hold on; plot(acrit*[1 1],[0 1],'k--');
set(gca,'FontSize',fs)
text(-0.15*acrit, 0.55, 'Pr(H), SiO2','Rotation',90); xlim([0 1.5*acrit]);
grid on;
disp(['med, mad, w, zt, SiO2=' num2str([999 999 w zt])]);

%------------------------------------------------------
% Water Temperature
%------------------------------------------------------
dat=load('../data/Corrected_welltemp.lldtz');
d=dat(:,3);
zt=zt_temp;
Prc=Prc_welltemp;
med=-0.1396;  %this is for the whole dataset whereas whats in the above file is only > 0
mad=1.9989;

dcrit=dcrit_welltemp;
d0=dcrit*[0:0.01:1.5]';  
a0=(d0-med)/mad-zt;

a0=max([a0 zeros(size(a0))]')';
acrit=(dcrit-med)/mad-zt;
w=(log(Prc/(1-Prc))-w0)./acrit; Pr=1./(1+exp(-w0-w.*a0));

subplot('position',[x1 y1-4*(ht+ybuf)-2*ybuf2 wid ht]);
plot(d0,Pr,'b-'); hold on; plot(dcrit*[1 1],[0 1],'k--');
text(0.7*dcrit,1.25, ['Excess water temp (^oC)'],'FontSize',fs);
set(gca,'XaxisLocation','top','FontSize',fs)
axis tight; grid on;
xlim([0 1.5*dcrit]);
text(0.1*dcrit,0.8,['Prc/Prc_r_i_f_t=' num2str(Prc/Prc_rift)]);
percdcrit=sum(d>=dcrit)/length(d)*100; text(1.03*dcrit,0.2,[num2str(percdcrit) '%']);

subplot('position',[x1 y1-5*(ht+ybuf)-2*ybuf2 wid ht]);
plot(a0,Pr,'b-'); hold on; plot(acrit*[1 1],[0 1],'k--');
set(gca,'FontSize',fs)
xlim([0 1.5*acrit]); grid on;
text(-0.15*acrit, 0.55, 'Pr(H), Water Temp.','Rotation',90); 
disp(['med, mad, w, zt water temp=' num2str([med mad w zt])]);
end;
if(0);
subplot(221)
hist(d,bins); hold on;
plot([median(d) median(d)], 3/bins*length(d)*[0 1],'k-','LineWidth',2);
plot([dcrit dcrit],3/bins*length(d)*[0 1],'k--','LineWidth',2);
xlabel('Data');
grid on;
end;


