%==========================================
% Reads rift zone picks and converts to map of probability
%==========================================

clear;
%------------------------------------------------------------------------------------------------------
%Grid with 1's on rift zones 0's off 
%------------------------------------------------------------------------------------------------------
dat=load('onrift.xyz');
lon=dat(:,1); lat=dat(:,2); 
nlat=min(find(lat(2:end)~=lat(1:end-1)));
nlon=length(lat)./nlat;
long=reshape(lon,nlat,nlon)';
latg=reshape(lat,nlat,nlon)';
onriftg=reshape(dat(:,3),nlat,nlon)';

%-------------------------------------------------------------------------
% Convolving function is the complement of the Michaelis-Menten function
%-------------------------------------------------------------------------
fac=0.2;
lonw=long(1,end)-long(1,1);
dlon=long(1,2)-long(1,1);
latw=latg(1,1)-latg(end,1);
dlat=latg(1,1)-latg(2,1);
lw=max(long(1,end)-long(1,1),latg(1,1)-latg(end,1))

R=0.5/111.18; 

[lonf latf]=meshgrid([-fac*lw:dlon:fac*lw],[-fac*lw:dlat:fac*lw]);
r=sqrt(lonf.^2+latf.^2);
f=1-abs(r)./(R+abs(r));  %Michaelis-Menten


%--------------------------------------------------------------------------
% Convolve rift zone points to compute "proximity to rift zone" attribute
%---------------------------------------------------------------------------

arift=conv2(onriftg,f,'same');
    
%--------------------------------------------------------------------------
figure(1); clf;
subplot(221);
pcolor(long,latg,onriftg); shading interp
xlabel('lon'); ylabel('lat');

subplot(222);
pcolor(lonf,latf,f); shading interp; 

subplot(223);
pcolor(long,latg,arift); shading interp;
colorbar

