%=======================================================================
% Takes water well locations and creates a model
% of the capture zone by mapping trajectories back up the hydraulic
% gradient.  The hydraulic head h is assumed to be the sum of the radial
% depression of around the well, a field that is propotional topography, 
% and a field that is proportional to average rainfall.  
% h=hp+ht+hr;
% I them use Matlab's function stream2 to compute tractectories up the
% gradients in h from several different point encircling the well.
%========================================================================
clear;
C1=2;
r0=1;   %radial distance where the BCs are set
rf1=2.5;  %radius of starting points to track streamlines
dq=1;
lon0=-155.5; lat0=19.6;
sig=1;  %sigma of Gaussian smoother (km);
x0=55; y0=-7;
x0=-35; y0=-45;
x0=65; y0=-7;
%x0=60; y0=-10;
%x0=20; y0=30;

%------------------------------------------------------------------------
%topo grid
%------------------------------------------------------------------------
if (exist('top')==0);
[lon,lat,top]=grdread2('../data/himbsyn_cut_0.002.grd');
[Lon,Lat]=meshgrid(lon,lat);
%[X,Y,zone,zonlims]=d2u(Lon,Lat);  %this conversion prevents stream2 
X=(Lon-lon0)*111.18*cosd(lat0); Y=(Lat-lat0)*111.18;
dx=X(1,2)-X(1,1);
dy=Y(2,1)-Y(1,1);
end;
nx1=floor(5*sig./dx)+1; ny1=floor(5*sig./dy);
[Xc,Yc]=meshgrid([-nx1*dx:dx:nx1*dx],[-ny1*dy:dy:ny1*dy]);
r=sqrt(Xc.^2+Yc.^2);
g=exp(-0.5*(r./sig).^2);
htop=conv2(top,g,'same');ii=find(htop>0);
htop=htop./median(htop(ii));

%------------------------------------------------------------------------
% Local well pumping cone
%------------------------------------------------------------------------
[fx,fy]=gradient(htop,dx,dy);
grad=sqrt(fx.^2+fy.^2);
rs=rf1.*dx;  %radius of starting points to track streamlines
r=sqrt((X-x0).^2+(Y-y0).^2);
ii=find(r<=rs);
s0=mean(grad(ii));    %local gradient near the well
C1*s0*rs

hpump=C1*s0*rs*log(r./r0);

%----------------------------------------------------------------------
% Model hydraulic head and gradient
%-----------------------------------------------------------------------
ii=find(htop>0);
h=htop+hpump;
[dhdx,dhdy]=gradient(h,dx,dy);

%----------------------------------------------------------------------
% Flow paths
%-----------------------------------------------------------------------
rs=rf1.*dx;  %radius of starting points to track streamlines
ii=find(r<rs);
az0=atan2d(mean(dhdx(ii)),mean(dhdy(ii)));  %azimuth of gradient
azims=az0+[-175 -120:30:120 175]';
%azims=az0+[-90:30:90]';
rs=rf1.*dx;  %radius of starting points to track streamlines
xs=rs.*sind(azims)+x0; ys=rs*cosd(azims)+y0;
xy=mmstream2(X,Y,dhdx,dhdy,xs,ys);
%xy=stream2(X,Y,dhdx,dhdy,xs,ys);
xyarray=cell2mat(xy');

%----------------------------------------------------------------------
% Plots
%-----------------------------------------------------------------------
figure(1); clf;
contourf(X,Y,h,20); hold on;
colorbar
contour(X,Y,top,[-1 1]*0.0001,'k-','LineWidth',2);
plot(xyarray(:,1),xyarray(:,2),'k.')
plot(x0,y0,'ro');
%plot(xs,ys,'k.');
%quiver(X(1:dq:end,1:dq:end),Y(1:dq:end,1:dq:end),dhdx(1:dq:end,1:dq:end),dhdy(1:dq:end,1:dq:end))
%plot(xy{1,1}(:,1),xy{1,1}(:,2),'k-');
% plot(xy{1,2}(pnum,1),xy{1,2}(pnum,2),'k.');

axis('equal')
axis('tight')





