%-----------------------------------------------------------
% Uses FFt's to solve for the cooling of an initially 
% hot layer in an infinite space. 
% 3/23/14
%-----------------------------------------------------------
clear;
D=4e3;  %thickness of layer
dT=1000;    %excess temperature
kap=1e-6;   %m^2/s
kcond=4;    %W/m/K
dt=0.01;
dz=0.5;

%----------------------------------------------------------------
% Initialize/define distance, wavenumber, and wavelength array
% nx=length of distance array
% nk=nx/2 because max. wavenumber is the inverse of twice the grid
%    interval.  This is the "Nyquist" frequency (or wavenumber)
% k and z0 must have same units (m)
%----------------------------------------------------------------
z=[-50:dz:50]'.*1e3;
nz=length(z);
kk=find(abs(z)<D/2);
T0=zeros(nz,1);
T0(kk)=dT;

nk=floor(nz./2);		%Max nk corresponds to Nyquist value
dk=2.*pi./(max(z)-min(z)+dz);		%Minimum wavenumber
if (nk < nz./2);                %Wavenumber array is 1/m
  k=[[0:nk] -[nk:-1:1]].*dk;	%if nz is odd
else
  k=[[0:nk] -[nk-1:-1:1]].*dk; %if nz is even
end;
k=k';
%----------------------------------------------------------------
%  Apply filters to FFT's of initial conditions
%----------------------------------------------------------------
my2sec=60*60*24*365.25*1e6;
t=[0:dt:5].*my2sec;
nt=length(t);

FT0=[fft(T0)*ones(1,nt)].*[exp(-kap.*[(k.^2)*t])];
T=ifft(FT0);

%----------------------------------------------------------------
%  Plot Solutions
%----------------------------------------------------------------
tplot=[dt 10*dt 100*dt 1000*dt];
figure(10); orient portrait; clf;
for k=1:length(tplot);
  ii=find(abs(t/my2sec-tplot(k))==min(abs(t/my2sec-tplot(k))));
  subplot(211);
  plot(z/1e3,T(:,ii),'r'); hold on;
end;
plot(z/1e3,T(:,1),'k');
grid on;
ylim([0 1.1.*dT])
ylabel('\DeltaT ^oC');
xlabel('Distance x, (km)');
Tmax=max(T,[],1);
Tmean=sum(T(kk,:),1)./length(kk)./dT;
% c1=[4:0.01:5];
% c2=[0.3:0.001:0.5];
% minmisfit=1e10;

% for i=1:length(c1);
%     %for j=1:length(c2);
%        
%     tau=((c1(i)*D/(2*pi)).^2)./kap;
%     %Tscale=exp(-(t./tau).^c2(j));
%     Tscale=exp(-(t./tau));
%     misfit=sum((Tscale-Tmean).^2);
%     if (misfit<minmisfit);
%         minmisfit=misfit;
%         %c2min=c2(j)
%         c1min=c1(i);
%     end;
%     %end;
% end;
c1min=2*pi; 
%c2min
tau=((c1min*D/(2*pi)).^2)./kap;
Dsol=sqrt(0.5*my2sec*kap)*2*pi/c1min

Tscale=exp(-(t./tau));
subplot(212);
plot(t./my2sec,(Tmean),'r'); hold on;
plot(t./my2sec,(Tscale),'k--'); 
grid on;
%axis([0 10 0 1]);
ylabel('(mean \DeltaT)/(\DeltaT_0) in original dike zone');
xlabel('Time (Myr)')

tnorm=[0:0.05:3];
%a=1.5*exp(-tnorm.^c2min)-0.5;
a=1.5*exp(-tnorm)-0.5;
figure(2);
subplot(211);
plot(exp(-tnorm),a);
xlabel('Tscale')
ylabel('a');
grid on;





  
