%-----------------------------------------------------------
% HW11
% Problem 2b.  Excess temperature and heatflow due to an 
% initially hot LAYER beneath Hawaiian Lithosphere
%-----------------------------------------------------------
clear;
zl=50e3;    %thickness of Hawaiian Lithosphere
dzp=100e3;  %thickness of plume layer
dT=1400;     %excess plume temperature
kap=1e-6;   %m^2/s
kcond=4;    %W/m/K
dt=1;
dz=0.5;
u0=80;

w=(3.5e-5)*dzp.*[100 300].*3300/2300/1e3;

%----------------------------------------------------------------
% Initialize/define distance, wavenumber, and wavelength array
% nx=length of distance array
% nk=nx/2 because max. wavenumber is the inverse of twice the grid
%    interval.  This is the "Nyquist" frequency (or wavenumber)
% k and z0 must have same units (m)
%----------------------------------------------------------------
z=[-400:dz:400]'.*1e3;
nz=length(z);
ii=find(abs(z)>zl & abs(z)<(zl+dzp));
T0=zeros(nz,1);
T0(ii)=sign(z(ii)).*dT;

nk=floor(nz./2);		%Max nk corresponds to Nyquist value
dk=2.*pi./(max(z)-min(z)+dz);		%Minimum wavenumber
if (nk < nz./2);                %Wavenumber array is 1/m
  k=[[0:nk] -[nk:-1:1]].*dk;	%if nz is odd
else
  k=[[0:nk] -[nk-1:-1:1]].*dk; %if nz is even
end;
k=k';
%----------------------------------------------------------------
%  Apply filters to FFT's of initial conditions
%----------------------------------------------------------------
my2sec=60*60*24*365.25*1e6;
t=[0:dt:100].*my2sec;
nt=length(t);

FT0=[fft(T0)*ones(1,nt)].*[exp(-kap.*[(k.^2)*t])];
T=ifft(FT0);
%q=kcond.*ifft(imag(FT0)+i.*real(FT0));
%q=kcond.*ifft([k*ones(1,nt)].*FT0);
Fq=i.*[k*ones(1,nt)].*FT0;
q=-kcond.*ifft(Fq);

%q=kcond.*ifft(i.*[sign(k)*ones(1,nt)].*[k*ones(1,nt)].*FT0);

%----------------------------------------------------------------
%  Apply filters to FFT's of initial conditions
%----------------------------------------------------------------
tplot=1;
while (tplot>-1)
  figure(1); orient portrait;
  ii=find(abs(t/my2sec-tplot)==min(abs(t/my2sec-tplot)));
  subplot(121);
    plot(T(:,ii),z/1e3); hold on;
    grid on;
    axis([0 1.1.*dT [0 max(z)]/1e3]);
    set(gca,'Ydir','reverse');
    xlabel('\DeltaT ^oC');
    ylabel('Depth (km)');
  subplot(122);
    plot(q(:,ii).*1e3,z/1e3); hold on;
    grid on;
    axis([-30 30 [0 max(z)]/1e3]);
    set(gca,'Ydir','reverse');
    xlabel('Heat flow q (mW/m^2)');
    ylabel('Depth (km)')
  tplot=input('Time to plot? (enter -1 to quit)>');
end;
ii=find(z==0);
figure(2); 
if (dT==100); clf; end;
bx=[0 t(nt)/my2sec t(nt)/my2sec 0 0];
by=[3  3 2 2 3];
subplot(211);
if (dT==100) fill(bx,by,[0.7 0.7 1]); hold on; end;
plot(t(2:nt)/my2sec,-q(ii,2:nt)*1e3,'k'); 
xlabel('time from hotspot (m.y.)');
ylabel('surface heatflow (mW/m^2)');
grid on;
subplot(212);
if (dT==100) fill(bx.*u0,by,[0.7 0.7 1]); hold on; end;
plot(u0.*t(2:nt)/my2sec,-q(ii,2:nt)*1e3,'k');
xlabel('distance from hotspot (km)');
ylabel('surface heatflow (mW/m^2)');
grid on;



  
