%========================================================================
% Testing depth function for seismicity
%========================================================================
%iplot=0;
if (exist('dens')==0); clear; end;
iplot=1;
%---------------------------------------------------------------------
% Compute dens of shallow earthquakes
%---------------------------------------------------------------------
secs=(2009.333-1992)*60*60*24*365.25;
yrs=2009.3333-1992;

x1=-156.2; x2=-154.7; y1=18.9; y2=20.3;
dat0=load('seismicity_dg_zc_rad_densc.txt');
dg=dat0(1); zc=dat0(2); rad=dat0(3); densc=dat0(4);
dg_zc_rad_densc=[dg zc rad densc]
%dg=1; zc=5.0; rad=5.0; densc=1.0;

dx=dg/111.18; dy=dg/(111.18*cosd((y1+y2)/2));  %evaluate frequencies at this grid spacing in km
nx=round((x2-x1)/dx); ny=round((y2-y1)/dy);
dx=(x2-x1)./nx; dy=(y2-y1)/ny;

dat=load('../data/Matoza_Shearer_etal_catalog_reformatted.txt');  
ii=find(dat(:,3)<=zc);
xd=dat(ii,2); yd=dat(ii,1); M=abs(dat(ii,4));
if (exist('dens')==0); xg=zeros(ny,nx); yg=xg; dens=xg; end;

k=0;
km2=0.5*pi*rad.^2;
%km2=pi*rad.^2;

if (max(dens(:))==0);
for i=1:nx;
    i
    for j=1:ny;
        k=k+1;
        xg(j,i)=x1+(i-0.5)*dx;  
        yg(j,i)=y1+(j-0.5)*dy;
        r=sqrt(((xd-xg(j,i))*111.18).^2+((yd-yg(j,i))*111.18*cosd((y1+y2)/2)).^2);
        ii=find(r<=rad );       
        dens(j,i)=sum((cos(pi.*r(ii)./rad)+1)./2)/km2/yrs;
        %dens(j,i)=length(ii)./km2./yrs;
        
    end;
end;
end;
%--------------------------------------------------------------------------
% Plots
%--------------------------------------------------------------------------
figure(2); clf;
dens0=[0:0.1:4]';
a0=2*(1-exp(-(dens0/(densc))));
%a0=log(dens0/densc);

haw=load('../data/hawaii_with_utm.txt');
subplot('position',[0.08 0.6 0.3 0.22]);
plot(dens0,a0)
%xlabel('seismicity (events/km^2/yr)')
ylabel('frequency/(reference freq.)')

w0=-2.1972;
w=abs(w0);
Pr0=[1+exp(-w0-w*a0)].^-1;

subplot('position',[0.08 0.32 0.3 0.22]);
plot(dens0,Pr0)
xlabel('frequency (events/km^2/yr)')
ylabel('Probability')

if (iplot);
a=dens./densc;
Pr=[1+exp(-w0-w*a)].^-1;

subplot('position',[0.55 0.55 0.4 0.4]);
pcolor(xg(1,:),yg(:,1),dens);
shading interp; hold on;
%caxis([0 2])
plot(haw(:,1),haw(:,2),'k-','LineWidth',2); 
axis([x1 x2 y1 y2]);
colorbar;
title('Scaled seismicity, events/km^2/yr');

subplot('position',[0.55 0.05 0.4 0.4]);
pcolor(xg(1,:),yg(:,1),Pr);
shading interp; hold on;
caxis([0 1])
plot(haw(:,1),haw(:,2),'k-','LineWidth',2); 
axis([x1 x2 y1 y2]);
colorbar;
title('Probability');
%xlabel('longitude'); ylabel('latitutde');

end;

out=[xg(:) yg(:) dens(:)];
fid=fopen('seismicity.xyf','w');
fprintf(fid,'%10.5f %10.5f %12.6f \n', out');
%fprintf(fid,'%10.5f %10.5f %5.3f \n', out');
fclose(fid);

