%========================================================================
% Testing depth function for seismicity
%========================================================================
clear xout;
%iplot=0;
if (exist('xout')==0); clear; end;
iplot=1;
%---------------------------------------------------------------------
% First just plot the test functions
%---------------------------------------------------------------------

zc=5;
z=[0:0.1:10];

a2=exp(-(z/zc).^2);
a4=exp(-(z/zc).^4);
a6=exp(-(z/zc).^6);

%---------------------------------------------------------------------
% Now find the shallowest (highest "a" value) in each grid on the map
% The grid spacing is ~gap (just a little less), where gap is the interpolation or uncertainty
% distance used to produce "a" using surface
%---------------------------------------------------------------------

x1=-156.2; x2=-154.7; y1=18.9; y2=20.3;
nx=751; ny=701; 
gap=load('Pperm_seismicity_gap.txt','ascii');
dx=gap*0.95; dy=gap*0.95;
nx=round((x2-x1)*111.18/dx); ny=round((y2-y1)*111.18*cosd((y1+y2)/2)/dy);
dx=(x2-x1)./nx; dy=(y2-y1)/ny;

disp(['Gap = ' num2str(gap) ' km']);

dat=load('../data/Seismicity_USGSquery_reformatted.txt'); xd=dat(:,1); yd=dat(:,2); zd=dat(:,3);
%dat=load('../data/Matoza_Shearer_etal_catalog_reformatted.txt');  xd=dat(:,2); yd=dat(:,1); zd=dat(:,3);
a=exp(-(zd./zc).^4);
xdum=zeros(nx*ny,1); ydum=xdum; adum=xdum; zdum=xdum;
k=0;


if (exist('xout')==0);
for i=1:nx;
    i
    for j=1:ny;
        xw=x1+(i-1)*dx;  xe=x1+i*dx; 
        ys=y1+(j-1)*dy; yn=y1+j*dy;
        ii=find(ys<yd & yd<=yn & xw<xd & xd<=xe);
        
        if (length(ii)>0);
            k=k+1;
            xdum(k)=(xw+xe)/2; ydum(k)=(ys+yn)/2; 
            zdum(k)=min(zd(ii)); 
            adum(k)=max(a(ii));
        end;
    end;
end;
ii=find(xdum~=0);
xout=xdum(ii); yout=ydum(ii); zout=zdum(ii); aout=adum(ii);
end;

if (iplot);
figure(2); clf;
subplot('position', [0.2 0.55 0.5 0.3]);
plot(z,a2,'r',z,a6,'b--'); hold on;
plot(z,a4,'k-','LineWidth',2)
%plot(zd,exp(-(zd./zc).^4),'k.')
xlabel('Earthquake depth (km)')
ylabel('scaled depth');
legend('exp(-(z/zc)^2)', 'exp(-(z/zc)^6)','exp(-(z/zc)^4)')
axis([0 15 0 1]);
grid on;


haw=load('../data/hawaii_with_utm.txt');

subplot('position',[0.05 0.05 0.4 0.4]);
scatter(xout,yout,200*dy,-zout,'fill'); hold on;
plot(haw(:,1),haw(:,2),'k-','LineWidth',2); 
caxis([-10 0]);
axis([x1 x2 y1 y2]);
colorbar;
%xlabel('longitude'); ylabel('latitutde');
title('Earthquake depths (km)');

subplot('position',[0.5 0.05 0.4 0.4]);
%scatter(dat(:,1),dat(:,2),30,exp(-(z/zc).^4),'fill'); hold on;
scatter(xout,yout,200*dy,aout,'fill'); hold on;
plot(haw(:,1),haw(:,2),'k-','LineWidth',2); 
axis([x1 x2 y1 y2]);
colorbar;
title('Scaled depths');
%xlabel('longitude'); ylabel('latitutde');
end;

out=[xout yout aout];
fid=fopen('seismicity.xya','w');
fprintf(fid,'%10.5f %10.5f %5.3f \n', out');
fclose(fid);

